@@ -27,4 +27,4 @@ elif [ -n "$AZURE_PYTHON_VERSION" ]; then
 fi
 
 export TOX_PARALLEL_NO_SPINNER=1
-exec $TOXPATH --parallel auto -e $($TOXPATH -l | grep "$searchstring" | tr $'\n' ',') -- "${@:2}"
+exec $TOXPATH -p auto -e $($TOXPATH -l | grep "$searchstring" | tr $'\n' ',') -- "${@:2}"
