@@ -7,19 +7,19 @@ if MYPY:
     from typing import Tuple
     from typing import Any
     from typing import Type
-
     from typing import TypeVar
 
     T = TypeVar("T")
 
 
 PY2 = sys.version_info[0] == 2
+PY33 = sys.version_info[0] == 3 and sys.version_info[1] >= 3
+PY37 = sys.version_info[0] == 3 and sys.version_info[1] >= 7
 
 if PY2:
-    import urlparse  # noqa
+    import urlparse
 
     text_type = unicode  # noqa
-    import Queue as queue  # noqa
 
     string_types = (str, text_type)
     number_types = (int, long, float)  # noqa
@@ -37,12 +37,11 @@ if PY2:
 
 else:
     import urllib.parse as urlparse  # noqa
-    import queue  # noqa
 
     text_type = str
     string_types = (text_type,)  # type: Tuple[type]
     number_types = (int, float)  # type: Tuple[type, type]
-    int_types = (int,)  # noqa
+    int_types = (int,)
     iteritems = lambda x: x.items()
 
     def implements_str(x):
@@ -59,12 +58,12 @@ else:
 
 def with_metaclass(meta, *bases):
     # type: (Any, *Any) -> Any
-    class metaclass(type):
+    class MetaClass(type):
         def __new__(metacls, name, this_bases, d):
             # type: (Any, Any, Any, Any) -> Any
             return meta(name, bases, d)
 
-    return type.__new__(metaclass, "temporary_class", (), {})
+    return type.__new__(MetaClass, "temporary_class", (), {})
 
 
 def check_thread_support():
@@ -87,6 +86,6 @@ def check_thread_support():
                 "We detected the use of uwsgi with disabled threads.  "
                 "This will cause issues with the transport you are "
                 "trying to use.  Please enable threading for uwsgi.  "
-                '(Enable the "enable-threads" flag).'
+                '(Add the "enable-threads" flag).'
             )
         )
