@@ -3,7 +3,7 @@ from os import environ
 import sys
 
 from sentry_sdk.hub import Hub, _should_send_default_pii
-from sentry_sdk.tracing import Transaction
+from sentry_sdk.tracing import TRANSACTION_SOURCE_COMPONENT, Transaction
 from sentry_sdk._compat import reraise
 from sentry_sdk.utils import (
     AnnotatedValue,
@@ -139,7 +139,10 @@ def _wrap_handler(handler):
             if headers is None:
                 headers = {}
             transaction = Transaction.continue_from_headers(
-                headers, op="serverless.function", name=aws_context.function_name
+                headers,
+                op="serverless.function",
+                name=aws_context.function_name,
+                source=TRANSACTION_SOURCE_COMPONENT,
             )
             with hub.start_transaction(
                 transaction,
@@ -374,7 +377,7 @@ def _make_request_event_processor(aws_event, aws_context, configured_timeout):
             if aws_event.get("body", None):
                 # Unfortunately couldn't find a way to get structured body from AWS
                 # event. Meaning every body is unstructured to us.
-                request["data"] = AnnotatedValue("", {"rem": [["!raw", "x", 0, 0]]})
+                request["data"] = AnnotatedValue.removed_because_raw_data()
 
         sentry_event["request"] = request
 
